package edu.mermet.tp8.fenetres;

import edu.mermet.tp8.UserXml;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.util.*;
import java.util.List;

/**
 * Classe permettant d'afficher une suggestion du jour
 */
public class FenetreSuggestion extends JInternalFrame {

    private ResourceBundle
            bundleAstuces = ResourceBundle.getBundle("Astuces/astuces", Locale.FRENCH);

    private UserXml userXML;

    private String libelleAstuce;
    private String astuceAffichee;

    /**
     * Constructeur FenetreSuggestion
     * @param u
     */
    public FenetreSuggestion(UserXml u){
        super("Suggestion du jour", false, true, false, false);
        userXML = u;

        this.ajouterClesAstucesUserXML();
        this.tirerAstuceEnCours();

        System.out.println(this.astuceAffichee);

        this.pack();
        this.setDefaultCloseOperation(EXIT_ON_CLOSE);

        this.setVisible(true);
    }

    /**
     * Ajoute les clés du fichier properties au fichier user.xml avec comme valeur par defaut (si non existantes) : true
     * Cela signifie que lorsqu'une clé du fichier user.xml a pour valeur true : elle peut potentiellement être affichée en suggestion du jour
     */
    public void ajouterClesAstucesUserXML(){
        Enumeration<String> cles = bundleAstuces.getKeys();

        while(cles.hasMoreElements()){
            String cle = cles.nextElement();
            if(userXML.getProperty(cle).equals("")){
                userXML.setProperty(cle, "true");
            }
        }

        userXML.save();

    }

    /**
     * Permet de tirer au hasard l'astuce à afficher
     */
    public void tirerAstuceEnCours(){

        List<String> listeLib = new ArrayList<>();
        listeLib.addAll(bundleAstuces.keySet());
        Collections.shuffle(listeLib);

        for(String astuce : listeLib){
            if(userXML.getProperty(astuce).equals("true")){
                this.libelleAstuce = astuce;
                break;
            }else{
                this.libelleAstuce = null;
            }
        }

        if(this.libelleAstuce == null) this.libelleAstuce = "";
        this.astuceAffichee = this.getAstuceDepuisLibelle();
    }

    /**
     * Retourne l'astuce associée au libellé stocké dans le fichier properties
     * @return String
     */
    public String getAstuceDepuisLibelle(){
        return bundleAstuces.getString(this.libelleAstuce);
    }

    /**
     * Classe permettant de quitter la fenêtre d'astuces
     */
    private class ActionFermer extends AbstractAction{
        public ActionFermer(){
            super("Fermer");
        }
        @Override
        public void actionPerformed(ActionEvent actionEvent) {
            setVisible(false);
        }
    }

    /**
     * Classe permettant de ne plus afficher l'astuce en cours
     */
    private class ActionNePlusAfficher extends AbstractAction{
        public ActionNePlusAfficher(){
            super("Ne plus afficher");
        }
        @Override
        public void actionPerformed(ActionEvent actionEvent) {
            setVisible(false);
            userXML.setProperty(libelleAstuce, "false");
            userXML.save();
        }
    }

}
